@@ -12,14 +12,16 @@ use POSIX qw(strftime);
 use Travel::Status::DE::DeutscheBahn::Result;
 use XML::LibXML;
 
-our $VERSION = '1.03';
+our $VERSION = '1.05';
 
 sub new {
 	my ( $obj, %conf ) = @_;
 	my $date = strftime( '%d.%m.%Y', localtime(time) );
 	my $time = strftime( '%H:%M',    localtime(time) );
 
-	my $ua = LWP::UserAgent->new();
+	my %lwp_options = %{ $conf{lwp_options} // { timeout => 10 } };
+
+	my $ua = LWP::UserAgent->new(%lwp_options);
 
 	$ua->env_proxy;
 
@@ -169,12 +171,13 @@ sub results {
 	my $re_morelink = qr{ date = (?<date> .. [.] .. [.] .. ) }x;
 
 	my @parts = (
-		[ 'time',     './td[@class="time"]' ],
-		[ 'train',    './td[3]' ],
-		[ 'route',    './td[@class="route"]' ],
-		[ 'dest',     './td[@class="route"]//a' ],
-		[ 'platform', './td[@class="platform"]' ],
-		[ 'info',     './td[@class="ris"]' ],
+		[ 'time',      './td[@class="time"]' ],
+		[ 'train',     './td[3]' ],
+		[ 'route',     './td[@class="route"]' ],
+		[ 'dest',      './td[@class="route"]//a' ],
+		[ 'platform',  './td[@class="platform"]' ],
+		[ 'info',      './td[@class="ris"]' ],
+		[ 'routeinfo', './td[@class="route"]//span[@class="red bold"]' ],
 	);
 
 	@parts = map { [ $_->[0], XML::LibXML::XPathExpression->new( $_->[1] ) ] }
@@ -198,7 +201,7 @@ sub results {
 
 		my @via;
 		my $first = 1;
-		my ( $time, $train, $route, $dest, $platform, $info )
+		my ( $time, $train, $route, $dest, $platform, $info, $routeinfo )
 		  = map { get_node( $tr, @{$_} ) } @parts;
 		my $e_train_more = ( $tr->findnodes($xp_train_more) )[0];
 
@@ -212,10 +215,11 @@ sub results {
 
 		substr( $date, 6, 0 ) = '20';
 
-		$platform //= q{};
-		$info     //= q{};
+		$platform  //= q{};
+		$info      //= q{};
+		$routeinfo //= q{};
 
-		for my $str ( $time, $train, $dest, $platform, $info ) {
+		for my $str ( $time, $train, $dest, $platform, $info, $routeinfo ) {
 			$str =~ s/\n/ /mg;
 			$str =~ tr/ //s;
 			$str =~ s/^ +//;
@@ -238,14 +242,15 @@ sub results {
 		push(
 			@{ $self->{results} },
 			Travel::Status::DE::DeutscheBahn::Result->new(
-				date      => $date,
-				time      => $time,
-				train     => $train,
-				route_raw => $route,
-				route     => \@via,
-				route_end => $dest,
-				platform  => $platform,
-				info_raw  => $info,
+				date          => $date,
+				time          => $time,
+				train         => $train,
+				route_raw     => $route,
+				route         => \@via,
+				route_end     => $dest,
+				platform      => $platform,
+				info_raw      => $info,
+				routeinfo_raw => $routeinfo,
 			)
 		);
 	}
@@ -286,7 +291,7 @@ arrival/departure monitor
 
 =head1 VERSION
 
-version 1.03
+version 1.05
 
 =head1 DESCRIPTION
 
@@ -326,6 +331,11 @@ Date to report for.  Defaults to the current day.
 Set language for additional information. Accepted arguments: B<d>eutsch,
 B<e>nglish, B<i>talian, B<n> (dutch).
 
+=item B<lwp_options> => I<\%hashref>
+
+Passed on to C<< LWP::UserAgent->new >>. Defaults to C<< { timeout => 10 } >>,
+you can use an empty hashref to override it.
+
 =item B<time> => I<hh>:I<mm>
 
 Time to report for.  Defaults to now.
@@ -352,7 +362,7 @@ By default, the following are shown: ice, ic_ec, d, nv, s.
 =item $status->errstr
 
 In case of an error in the HTTP request, returns a string describing it.  If
-no error occured, returns undef.
+no error occurred, returns undef.
 
 =item $status->results
 
