@@ -8,10 +8,10 @@ no if $] >= 5.018, warnings => "experimental::smartmatch";
 
 use parent 'Class::Accessor';
 
-our $VERSION = '1.04';
+our $VERSION = '1.05';
 
 Travel::Status::DE::DeutscheBahn::Result->mk_ro_accessors(
-	qw(date time train route_end route_raw platform info_raw));
+	qw(date time train route_end route_raw platform info_raw routeinfo_raw));
 
 sub new {
 	my ( $obj, %conf ) = @_;
@@ -62,6 +62,16 @@ sub delay {
 	return;
 }
 
+sub is_cancelled {
+	my ($self) = @_;
+	my $info = $self->info_raw;
+
+	if ( $info =~ m{ Fahrt \s f.llt \s aus }ox ) {
+		return 1;
+	}
+	return 0;
+}
+
 sub origin {
 	my ($self) = @_;
 
@@ -75,6 +85,17 @@ sub route {
 	return @stops;
 }
 
+sub route_info {
+	my ($self) = @_;
+
+	my $route_info = $self->routeinfo_raw;
+
+	$route_info =~ s{ ^ [\s\n]+ }{}x;
+	$route_info =~ s{ [\s\n]+ $ }{}x;
+
+	return $route_info;
+}
+
 sub route_interesting {
 	my ( $self, $max_parts ) = @_;
 
@@ -83,7 +104,7 @@ sub route_interesting {
 	$max_parts //= 3;
 
 	for my $stop (@via) {
-		if ( $stop =~ m{ ?Hbf}o ) {
+		if ( $stop =~ m{ Hbf | Flughafen }ox ) {
 			push( @via_main, $stop );
 		}
 	}
@@ -180,7 +201,7 @@ arrival/departure received by Travel::Status::DE::DeutscheBahn
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 DESCRIPTION
 
@@ -207,6 +228,10 @@ Returns the train's delay in minutes, or undef if it is unknown.
 Returns additional information, for instance the reason why the train is
 delayed. May be an empty string if no (useful) information is available.
 
+=item $result->is_cancelled
+
+True if the train was cancelled, false otherwise.
+
 =item $result->line
 
 =item $result->train
@@ -256,7 +281,7 @@ Note that all main stations will be stripped of their "Hbf" suffix.
 
 Returns the raw string used to create the route array.
 
-Note that canceled stops are filtered from B<route>, but still present in
+Note that cancelled stops are filtered from B<route>, but still present in
 B<route_raw>.
 
 =item $result->route_timetable
@@ -264,6 +289,11 @@ B<route_raw>.
 Similar to B<route>.  however, this function returns a list of array
 references of the form C<< [ arrival time, station name ] >>.
 
+=item $result->route_info
+
+Returns a string containing information related to the train's route, such as
+"landslide between X and Y, expect delays".
+
 =item $result->time
 
 Returns the arrival/departure time as string in "hh:mm" format.
